@@ -1,6 +1,7 @@
       SUBROUTINE ERM4(STA,STB)
+      IMPLICIT NONE
       CHARACTER*(*) STA,STB
-      PRINT *,'INVALID ',STA,' OPTION: ',STB
+C      PRINT *,'INVALID ',STA,' OPTION: ',STB
       CALL ERM0
       RETURN
       END
